OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "V mapo »config« ni mogoče zapisovati!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Lahko pustite dovoljenje datoteke config.php nastavljeno na le za branje, a je treba v datoteki nastaviti možnost »config_is_read_only« na PRAV.",
    "See %s" : "Oglejte si %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Program %1$s ni na voljo ali pa je nameščena neskladna različica za ta strežnik. Preverite mapo programov.",
    "Sample configuration detected" : "Zaznana je neustrezna vzorčna nastavitev",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "V sistem je bila kopirana datoteka s vzorčnimi nastavitvami. To lahko vpliva na namestitev in zato možnost ni podprta. Pred spremembami datoteke config.php si natančno preberite dokumentacijo.",
    "The page could not be found on the server." : "Strani na strežniku ni mogoče najti.",
    "Email verification" : "Overjanje elektronskega naslova",
    "Click the following link to confirm your email." : "Kliknite na povezavo za potrditev elektronskega naslova.",
    "Confirm your email" : "Potrditev gesla",
    "Other activities" : "Druge dejavnosti",
    "%1$s and %2$s" : "%1$s in %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s in %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s in %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s in %5$s",
    "Enterprise bundle" : "Poslovni paket",
    "Groupware bundle" : "Paket za skupinsko delo",
    "Hub bundle" : "Razvijalski paket",
    "Social sharing bundle" : "Paket družbene izmenjave",
    "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
    "PHP with a version lower than %s is required." : "Zahtevana je različica PHP nižja od %s.",
    "%sbit or higher PHP required." : "Zahtevana je %s-bitna različica PHP višja.",
    "The following architectures are supported: %s" : "Podprte so navedena okolja: %s",
    "The following databases are supported: %s" : "Podprte so navedene podatkovne zbirke: %s",
    "The command line tool %s could not be found" : "Orodja ukazne vrstice %s ni mogoče najti",
    "The library %s is not available." : "Knjižnica %s ni na voljo.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Zahtevana je knjižnica %1$s z različico, višjo od %2$s – na voljo je različica %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Zahtevana je knjižnica %1$s z različico, manjšo od %2$s – na voljo je različica %3$s.",
    "The following platforms are supported: %s" : "Podprta so okolja: %s",
    "Server version %s or higher is required." : "Zahtevana je različica strežnika %s ali višja.",
    "Server version %s or lower is required." : "Zahtevana je različica strežnika %s ali nižja.",
    "Wiping of device %s has started" : "Začeto je brisanje podatkov na napravi %s.",
    "Wiping of device »%s« has started" : "Začeto je brisanje podatkov na napravi »%s«",
    "»%s« started remote wipe" : "Program »%s« je začel izvajati oddaljeno varnostno brisanje",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Naprava ali program »%s« je začel izvajati oddaljeno varnostno brisanje. Ko bo opravilo končano boste prejeli še eno sporočilo.",
    "Wiping of device %s has finished" : "Brisanje podatkov na napravi %s je končano.",
    "Wiping of device »%s« has finished" : "Brisanje podatkov na napravi »%s« je končano.",
    "»%s« finished remote wipe" : "Program »%s« je zaključil z izvajanjem oddaljenega varnostnega brisanja.",
    "Device or application »%s« has finished the remote wipe process." : "Naprava ali program »%s« je zaključil oddaljeno varnostno brisanje.",
    "Remote wipe started" : "Začeto je oddaljeno varnostno brisanje",
    "A remote wipe was started on device %s" : "Začeto je bilo oddaljeno varnostno brisanje na napravi %s.",
    "Remote wipe finished" : "Oddaljeno varnostno brisanje je končano",
    "The remote wipe on %s has finished" : "Oddaljeno varnostno brisanje na %s je končano",
    "Authentication" : "Overitev",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "Avatar image is not square" : "Slika podobe ni kvadratna",
    "Files" : "Datoteke",
    "View profile" : "Pokaži profil",
    "Local time: %s" : "Krajevni čas: %s",
    "today" : "danes",
    "tomorrow" : "jutri",
    "yesterday" : "včeraj",
    "_in %n day_::_in %n days_" : ["čez %n dan","čez %n dneva","čez %n dni","čez %n dni"],
    "_%n day ago_::_%n days ago_" : ["pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"],
    "next month" : "naslednji mesec",
    "last month" : "zadnji mesec",
    "_in %n month_::_in %n months_" : ["čez %n mesec","čez %n meseca","čez %n mesece","čez %n mesecev"],
    "_%n month ago_::_%n months ago_" : ["pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"],
    "next year" : "naslednje leto",
    "last year" : "lansko leto",
    "_in %n year_::_in %n years_" : ["čez %n leto","čez %n leti","čez %n leta","čez %n let"],
    "_%n year ago_::_%n years ago_" : ["pred %n letom","pred %n letoma","pred %n leti","pred %n leti"],
    "_in %n hour_::_in %n hours_" : ["čez %n uro","čez %n uri","čez %n ure","čez %n ur"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n uro","pred %n urama","pred %n urami","pred %n urami"],
    "_in %n minute_::_in %n minutes_" : ["čez %n minuto","čez %n minuti","čez %n minute","čez %n minut"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"],
    "in a few seconds" : "čez nekaj sekund",
    "seconds ago" : "pred nekaj sekundami",
    "Empty file" : "Prazna datoteka",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul z ID: %s ne obstaja. Omogočite ga med nastavitvami, ali pa stopite v stik s skrbnikom sistema.",
    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
    "File already exists" : "Datoteka že obstaja",
    "Invalid path" : "Neveljavna pot",
    "Failed to create file from template" : "Ustvarjanje datoteke iz predloge je spodletelo",
    "Templates" : "Predloge",
    "Filename contains at least one invalid character" : "Ime datoteke vsebuje vsaj en neveljaven znak.",
    "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programa »%s« ni mogoče namestiti, ker datoteke appinfo ni mogoče brati.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programa »%s« ni mogoče namestiti, ker ni združljiv z nameščeno različico strežnika.",
    "__language_name__" : "Slovenščina",
    "This is an automatically sent email, please do not reply." : "To sporočilo je samodejno poslano, nanj se nima smisla odzvati.",
    "Appearance and accessibility" : "Videz in dostopnost",
    "Apps" : "Programi",
    "Personal settings" : "Osebne nastavitve",
    "Administration settings" : "Skrbniške nastavitve",
    "Settings" : "Nastavitve",
    "Log out" : "Odjava",
    "Accounts" : "Računi",
    "Email" : "Elektronski naslov",
    "Mail %s" : "Elektronski naslov %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Oglejte si %s na fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Klic %s",
    "Twitter" : "Račun Twitter",
    "View %s on Twitter" : "Oglejte si %s na Twitter",
    "Website" : "Spletna stran",
    "Visit %s" : "Obišči %s",
    "Address" : "Naslov",
    "Profile picture" : "Slika profila",
    "About" : "O programu",
    "Display name" : "Prikazno ime",
    "Headline" : "Naslov",
    "Organisation" : "Ustanova",
    "Role" : "Vloga",
    "Additional settings" : "Dodatne nastavitve",
    "Enter the database name for %s" : "Vpis imena podatkovne zbirke za %s.",
    "You cannot use dots in the database name %s" : "V imenu podatkovne zbirke %s ni dovoljeno uporabljati pik.",
    "You need to enter details of an existing account." : "Vpisati je treba podrobnosti obstoječega računa.",
    "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najboljše rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kaže, da je dejavna seja %s zagnana v 32-bitnem okolju PHP in, da je v datoteki php.ini nastavljen open_basedir . Tako delovanje ni priporočljivo, saj se lahko pojavijo težave z datotekami, večjimi od 4GB.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraniti je treba nastavitev open_basedir v datoteki php.ini ali pa preklopiti na 64-bitno okolje PHP.",
    "Set an admin password." : "Nastavi skrbniško geslo.",
    "Cannot create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
    "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
    "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vam omogoča souporabo »%2$s« in želi dodati:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s vam omogoča souporabo »%2$s« in želi dodati",
    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
    "Unknown share type" : "Neznana vrsta mesta souporabe",
    "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
    "Cannot increase permissions of %s" : "Ni mogoče povečati dovoljen %s",
    "Files cannot be shared with delete permissions" : "Souporaba datotek z nastavljenim dovoljenjem za brisanje ni mogoča",
    "Files cannot be shared with create permissions" : "Souporaba datotek z nastavljenim dovoljenjem za ustvarjanje ni mogoča",
    "Expiration date is in the past" : "Datum preteka je že mimo!",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datuma pretaka ni mogoče nastaviti za več kot %n dan v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dneva v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dni v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dni v prihodnost."],
    "Sharing is only allowed with group members" : "Souporaba je dovoljena le med člani skupine",
    "The requested share does not exist anymore" : "Podano mesto souporabe ne obstaja več",
    "Could not find category \"%s\"" : "Kategorije »%s« ni mogoče najti.",
    "Sunday" : "nedelja",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sun." : "ned",
    "Mon." : "pon",
    "Tue." : "tor",
    "Wed." : "sre",
    "Thu." : "čet",
    "Fri." : "pet",
    "Sat." : "sob",
    "Su" : "ne",
    "Mo" : "po",
    "Tu" : "to",
    "We" : "sr",
    "Th" : "če",
    "Fr" : "pe",
    "Sa" : "so",
    "January" : "januar",
    "February" : "februar",
    "March" : "marec",
    "April" : "april",
    "May" : "maj",
    "June" : "junij",
    "July" : "julij",
    "August" : "avgust",
    "September" : "september",
    "October" : "oktober",
    "November" : "november",
    "December" : "december",
    "Jan." : "jan",
    "Feb." : "feb",
    "Mar." : "mar",
    "Apr." : "apr",
    "May." : "maj",
    "Jun." : "jun",
    "Jul." : "jul",
    "Aug." : "avg",
    "Sep." : "sep",
    "Oct." : "okt",
    "Nov." : "nov",
    "Dec." : "dec",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "Login canceled by app" : "Program onemogoča prijavo",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programa »%1$s« ni mogoče namestiti zaradi nerešenih odvisnosti: %2$s",
    "a safe home for all your data" : "Varno okolje za vaše podatke!",
    "File is currently busy, please try again later" : "Datoteka je trenutno v uporabi. Poskusite znova kasneje.",
    "Cannot download file" : "Datoteke ni mogoče prejeti",
    "Application is not enabled" : "Program ni omogočen",
    "Authentication error" : "Napaka overjanja",
    "Token expired. Please reload page." : "Žeton je pretekel. Stran je treba ponovno naložiti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ni nameščenih programnikov podatkovnih zbirk (sqlite, mysql oziroma postgresql).",
    "Cannot write into \"config\" directory." : "V mapo »config« ni mogoče zapisovati!",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo. Poglejte %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Lahko pustite dovoljenje datoteke config.php nastavljeno na le za branje, a je treba v datoteki nastaviti možnost »config_is_read_only« na PRAV. Več o tem si lahko preberete na %s",
    "Cannot write into \"apps\" directory." : "V mapo »apps« ni mogoče zapisovati!",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v mapo programov, ali pa z onemogočanjem zbirke programov v nastavitveni datoteki.",
    "Cannot create \"data\" directory." : "Ni mogoče ustvariti »podatkovne« mape",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v korensko mapo. Poglejte %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Omejitev je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v korensko mapo. Za več podrobnosti si oglejte %s.",
    "Your data directory is not writable." : "Podatkovna mapa ni zapisljiva.",
    "Setting locale to %s failed." : "Nastavljanje jezikovnih določil na %s je spodletelo.",
    "Please install one of these locales on your system and restart your web server." : "Namestiti je treba podporo za vsaj eno od navedenih jezikovnih določil v sistemu in nato ponovno zagnati spletni strežnik.",
    "PHP module %s not installed." : "Modul PHP %s ni nameščen.",
    "Please ask your server administrator to install the module." : "Obvestite skrbnika strežnika, da je treba namestiti manjkajoč modul.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Nastavitev PHP »%s« ni nastavljena na »%s«.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Prilagoditev te nastavitve v php.ini vzpostavi ponovno delovanje okolja NextCloud",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Vrednost <code>mbstring.func_overload</code> je nastavljena na <code>%s</code> in ne na pričakovano vrednost <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Za rešitev težave je treba v datoteki php.ini nastaviti možnost <code>mbstring.func_overload</code> na <code>0</code>.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : " Kaže, da je PHP nastavljen tako, da odreže vrstične predmete docblock. To povzroči, da nekateri jedrni programi niso dosegljivi.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
    "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
    "Your data directory must be an absolute path." : "Podatkovna mapa mora imeti navedeno celotno pot.",
    "Your data directory is invalid." : "Podatkovna mapa ni veljavna.",
    "Action \"%s\" not supported or implemented." : "Dejanje »%s« ni podprto ali omogočeno.",
    "Authentication failed, wrong token or provider ID given" : "Overitev je spodletela, podan je napačen žeton oziroma določilo ID ponudnika",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Manjkajo parametri za dokončanje zahteve: »%s«.",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Določilo ID »%1$s« je že v uporabi pri ponudniku zveznega oblaka »%2$s«.",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Ponudnik zveznega povezovanja z ID: »%s« ne obstaja.",
    "Could not obtain lock type %d on \"%s\"." : "Ni mogoče pridobiti zaklepa %d na \"%s\".",
    "Storage unauthorized. %s" : "Dostop do shrambe ni overjen. %s",
    "Storage incomplete configuration. %s" : "Nepopolna nastavitev shrambe. %s",
    "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
    "Writing style" : "Slog pisanja",
    "Generate image" : "Ustvari sliko",
    "Summary" : "Povzetek",
    "Translate" : "Prevedi",
    "Target language" : "Ciljni jezik",
    "Result" : "Rezultat",
    "Education Edition" : "Izobraževalna različica",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljen uporabnik mora biti določen za skrbnika, pomočnika skrbnika ali pa mora imeti dodeljene posebna dovoljenja za dostop do nastavitve.",
    "Logged in user must be an admin or sub admin" : "Prijavljen uporabnik mora imeti dovoljenja skrbnika ali podpornega skrbnika",
    "Logged in user must be an admin" : "Prijavljen uporabnik mora biti tudi skrbnik",
    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en nedovoljen znak.",
    "File name is too long" : "Ime datoteke je predolgo",
    "Help" : "Pomoč",
    "Users" : "Uporabniki",
    "Unknown user" : "Neznan uporabnik",
    "Enter the database username and name for %s" : "Vpis uporabniškega imena in imena podatkovne zbirke za %s.",
    "Enter the database username for %s" : "Vpis uporabniškega imena podatkovne zbirke za %s.",
    "MySQL username and/or password not valid" : "Uporabniško ime ali geslo MySQL ni veljavno",
    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
    "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet že v souporabi z uporabnikom %s.",
    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
    "Could not create user" : "Uporabnika ni mogoče ustvariti",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: »a–z«, »A–Z«, »0–9«, presledki in »_.@-«\".",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
    "Username must not consist of dots only" : "Uporabniško ime ne sme biti zgolj iz pik",
    "Username is invalid because files already exist for this user" : "Uporabniško ime ni veljavno, ker za tega uporabnika že obstajajo datoteke",
    "User disabled" : "Uporabnik je onemogočen",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Prepričajte se, da je datoteka ».ocdata« v korenu podatkovne mape."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
